@@ -11,7 +11,11 @@ FQN = f"{SCHEMA}.{TABLE}"
 @pytest.fixture()
 def TEST_TABLE():
     run_sql_task = AzureSQLDBQuery()
-    run_sql_task.run(f"CREATE TABLE {FQN} (id INT, name VARCHAR(25))")
+    run_sql_task.run(
+        f""" 
+            DROP TABLE IF EXISTS {FQN};
+            CREATE TABLE {FQN} (id INT, name VARCHAR(25))"""
+    )
     run_sql_task.run(f"INSERT INTO {FQN} VALUES (1, 'Mike')")
     yield
     run_sql_task.run(f"DROP TABLE {FQN}")
