@@ -7,7 +7,7 @@ from prefect import Flow
 from prefect.backend import set_key_value
 from prefect.utilities import logging
 
-from ..task_utils import (
+from viadot.task_utils import (
     add_ingestion_metadata_task,
     df_get_data_types_task,
     df_map_mixed_dtypes_for_parquet,
@@ -16,11 +16,8 @@ from ..task_utils import (
     dtypes_to_json_task,
     update_dtypes_dict,
 )
-from ..tasks import AzureDataLakeUpload, BigQueryToDF
+from viadot.tasks import AzureDataLakeUpload, BigQueryToDF
 
-bigquery_to_df_task = BigQueryToDF()
-file_to_adls_task = AzureDataLakeUpload()
-json_to_adls_task = AzureDataLakeUpload()
 
 logger = logging.get_logger(__name__)
 
@@ -29,6 +26,7 @@ class BigQueryToADLS(Flow):
     def __init__(
         self,
         name: str = None,
+        query: str = None,
         dataset_name: str = None,
         table_name: str = None,
         date_column_name: str = "date",
@@ -36,7 +34,6 @@ class BigQueryToADLS(Flow):
         end_date: str = None,
         credentials_key: str = "BIGQUERY",
         vault_name: str = None,
-        credentials_secret: str = None,
         output_file_extension: str = ".parquet",
         adls_dir_path: str = None,
         local_file_path: str = None,
@@ -44,20 +41,24 @@ class BigQueryToADLS(Flow):
         adls_sp_credentials_secret: str = None,
         overwrite_adls: bool = False,
         if_exists: str = "replace",
+        timeout: int = 3600,
         *args: List[Any],
         **kwargs: Dict[str, Any],
     ):
         """
-        Flow for downloading data from BigQuery project to a local CSV or Parquet file
-        using Bigquery API, then uploading it to Azure Data Lake.
+        Flow for downloading data from BigQuery project to a local CSV or Parquet file using
+        Bigquery API, then uploading it to Azure Data Lake.
+        For querying on database user have to provide `query` parameter OR `dataset` and `table_name`.
 
-        There are 3 cases:
+        If user does not provide `query` there are 3 cases:
             If start_date and end_date are not None - all data from the start date to the end date will be retrieved.
             If start_date and end_date are left as default (None) - the data is pulled till "yesterday" (current date -1)
             If the column that looks like a date does not exist in the table, get all the data from the table.
 
         Args:
             name (str): The name of the flow.
+            query(str, optional): SQL query to querying data in BigQuery. Format of basic query: (SELECT * FROM `{project}.{dataset_name}.{table_name}`)
+                Defaults to None.
             dataset_name (str, optional): Dataset name. Defaults to None.
             table_name (str, optional): Table name. Defaults to None.
             date_column_name (str, optional): The query is based on a date, the user can provide the name
@@ -65,9 +66,8 @@ class BigQueryToADLS(Flow):
             all data will be retrieved from the table. Defaults to "date".
             start_date (str, optional): A query parameter to pass start date e.g. "2022-01-01". Defaults to None.
             end_date (str, optional): A query parameter to pass end date e.g. "2022-01-01". Defaults to None.
-            credentials_key (str, optional): Credential key to dictionary where details are stored (local config).
-            credentials can be generated as key for User Principal inside a BigQuery project. Defaults to "BIGQUERY".
-            credentials_secret (str, optional): The name of the Azure Key Vault secret for Bigquery project. Defaults to None.
+            credentials_key (str, optional): Credential key to dictionary where details are stored - Azure Key Vault or local config.
+                credentials can be generated as key for User Principal inside a BigQuery project. Defaults to "BIGQUERY".
             vault_name (str, optional): The name of the vault from which to obtain the secrets. Defaults to None.
             output_file_extension (str, optional): Output file extension - to allow selection of.csv for data
             which is not easy to handle with parquet. Defaults to ".parquet".
@@ -79,16 +79,18 @@ class BigQueryToADLS(Flow):
             Defaults to None.
             overwrite_adls (bool, optional): Whether to overwrite files in the lake. Defaults to False.
             if_exists (str, optional): What to do if the file exists. Defaults to "replace".
+            timeout(int, optional): The amount of time (in seconds) to wait while running this task before
+                a timeout occurs. Defaults to 3600.
         """
         # BigQueryToDF
-        self.credentials_key = credentials_key
+        self.query = query
         self.dataset_name = dataset_name
         self.table_name = table_name
         self.start_date = start_date
         self.end_date = end_date
         self.date_column_name = date_column_name
         self.vault_name = vault_name
-        self.credentials_secret = credentials_secret
+        self.credentials_key = credentials_key
 
         # AzureDataLakeUpload
         self.overwrite = overwrite_adls
@@ -96,6 +98,7 @@ class BigQueryToADLS(Flow):
         self.if_exists = if_exists
         self.output_file_extension = output_file_extension
         self.now = str(pendulum.now("utc"))
+        self.timeout = timeout
 
         self.local_file_path = (
             local_file_path or self.slugify(name) + self.output_file_extension
@@ -125,7 +128,9 @@ class BigQueryToADLS(Flow):
         return name.replace(" ", "_").lower()
 
     def gen_flow(self) -> Flow:
+        bigquery_to_df_task = BigQueryToDF(timeout=self.timeout)
         df = bigquery_to_df_task.bind(
+            query=self.query,
             dataset_name=self.dataset_name,
             table_name=self.table_name,
             credentials_key=self.credentials_key,
@@ -133,7 +138,6 @@ class BigQueryToADLS(Flow):
             end_date=self.end_date,
             date_column_name=self.date_column_name,
             vault_name=self.vault_name,
-            credentials_secret=self.credentials_secret,
             flow=self,
         )
 
@@ -158,6 +162,7 @@ class BigQueryToADLS(Flow):
                 flow=self,
             )
 
+        file_to_adls_task = AzureDataLakeUpload(timeout=self.timeout)
         file_to_adls_task.bind(
             from_path=self.local_file_path,
             to_path=self.adls_file_path,
@@ -171,6 +176,7 @@ class BigQueryToADLS(Flow):
             dtypes_dict=dtypes_updated, local_json_path=self.local_json_path, flow=self
         )
 
+        json_to_adls_task = AzureDataLakeUpload(timeout=self.timeout)
         json_to_adls_task.bind(
             from_path=self.local_json_path,
             to_path=self.adls_schema_file_dir_file,
