@@ -2,9 +2,7 @@ from typing import Any, Dict, List
 
 from prefect import Flow
 
-from ..tasks.duckdb import DuckDBQuery
-
-query_task = DuckDBQuery()
+from viadot.tasks.duckdb import DuckDBQuery
 
 
 class DuckDBTransform(Flow):
@@ -14,6 +12,7 @@ class DuckDBTransform(Flow):
         query: str,
         credentials: dict = None,
         tags: List[str] = ["transform"],
+        timeout: int = 3600,
         *args: List[any],
         **kwargs: Dict[str, Any]
     ):
@@ -25,16 +24,19 @@ class DuckDBTransform(Flow):
             query (str, required): The query to execute on the database.
             credentials (dict, optional): Credentials for the connection. Defaults to None.
             tags (list, optional): Tag for marking flow. Defaults to "transform".
+            timeout(int, optional): The amount of time (in seconds) to wait while running this task before
+                a timeout occurs. Defaults to 3600.
         """
         self.query = query
         self.credentials = credentials
         self.tags = tags
-        self.tasks = [query_task]
+        self.timeout = timeout
 
         super().__init__(*args, name=name, **kwargs)
         self.gen_flow()
 
     def gen_flow(self) -> Flow:
+        query_task = DuckDBQuery(timeout=self.timeout)
         query_task.bind(
             query=self.query,
             credentials=self.credentials,
