@@ -2,8 +2,8 @@ from typing import Any, Dict, List, Literal
 
 from prefect import Flow
 
-from ..task_utils import add_ingestion_metadata_task, cast_df_to_str, df_to_parquet
-from ..tasks import DuckDBCreateTableFromParquet, EpicorOrdersToDF
+from viadot.task_utils import add_ingestion_metadata_task, cast_df_to_str, df_to_parquet
+from viadot.tasks import DuckDBCreateTableFromParquet, EpicorOrdersToDF
 
 
 class EpicorOrdersToDuckDB(Flow):
@@ -15,6 +15,7 @@ class EpicorOrdersToDuckDB(Flow):
         local_file_path: str,
         epicor_credentials: Dict[str, Any] = None,
         epicor_config_key: str = None,
+        validate_date_filter: bool = True,
         start_date_field: str = "BegInvoiceDate",
         end_date_field: str = "EndInvoiceDate",
         duckdb_table: str = None,
@@ -22,6 +23,7 @@ class EpicorOrdersToDuckDB(Flow):
         if_exists: Literal["fail", "replace", "append", "skip", "delete"] = "fail",
         if_empty: Literal["warn", "skip", "fail"] = "skip",
         duckdb_credentials: dict = None,
+        timeout: int = 3600,
         *args: List[any],
         **kwargs: Dict[str, Any],
     ):
@@ -35,6 +37,7 @@ class EpicorOrdersToDuckDB(Flow):
             epicor_credentials (Dict[str, Any], optional): Credentials to connect with Epicor API containing host, port,
                 username and password. Defaults to None.
             epicor_config_key (str, optional): Credential key to dictionary where details are stored. Defaults to None.
+            validate_date_filter (bool, optional): Whether or not validate xml date filters. Defaults to True.
             start_date_field (str, optional) The name of filters field containing start date. Defaults to "BegInvoiceDate".
             end_date_field (str, optional) The name of filters field containing end date. Defaults to "EndInvoiceDate".
             duckdb_table (str, optional): Destination table in DuckDB. Defaults to None.
@@ -42,10 +45,13 @@ class EpicorOrdersToDuckDB(Flow):
             if_exists (Literal, optional):  What to do if the table already exists. Defaults to "fail".
             if_empty (Literal, optional): What to do if Parquet file is empty. Defaults to "skip".
             duckdb_credentials (dict, optional): Credentials for the DuckDB connection. Defaults to None.
+            timeout(int, optional): The amount of time (in seconds) to wait while running this task before
+                a timeout occurs. Defaults to 3600.
         """
         self.base_url = base_url
         self.epicor_credentials = epicor_credentials
         self.epicor_config_key = epicor_config_key
+        self.validate_date_filter = validate_date_filter
         self.filters_xml = filters_xml
         self.end_date_field = end_date_field
         self.start_date_field = start_date_field
@@ -61,9 +67,11 @@ class EpicorOrdersToDuckDB(Flow):
         self.df_task = EpicorOrdersToDF(
             base_url=self.base_url,
             filters_xml=self.filters_xml,
+            timeout=timeout,
         )
         self.create_duckdb_table_task = DuckDBCreateTableFromParquet(
-            credentials=duckdb_credentials
+            credentials=duckdb_credentials,
+            timeout=timeout,
         )
 
         self.gen_flow()
@@ -73,6 +81,7 @@ class EpicorOrdersToDuckDB(Flow):
             flow=self,
             credentials=self.epicor_credentials,
             config_key=self.epicor_config_key,
+            validate_date_filter=self.validate_date_filter,
             end_date_field=self.end_date_field,
             start_date_field=self.start_date_field,
         )
