@@ -2,10 +2,8 @@ from typing import Any, Dict, List, Literal
 
 from prefect import Flow
 
-from ..task_utils import add_ingestion_metadata_task, cast_df_to_str, df_to_parquet
-from ..tasks import DuckDBCreateTableFromParquet, SQLServerToDF
-
-df_task = SQLServerToDF()
+from viadot.task_utils import add_ingestion_metadata_task, cast_df_to_str, df_to_parquet
+from viadot.tasks import DuckDBCreateTableFromParquet, SQLServerToDF
 
 
 class SQLServerToDuckDB(Flow):
@@ -20,6 +18,7 @@ class SQLServerToDuckDB(Flow):
         if_exists: Literal["fail", "replace", "append", "skip", "delete"] = "fail",
         if_empty: Literal["warn", "skip", "fail"] = "skip",
         duckdb_credentials: dict = None,
+        timeout: int = 3600,
         *args: List[any],
         **kwargs: Dict[str, Any],
     ):
@@ -37,11 +36,13 @@ class SQLServerToDuckDB(Flow):
             if_exists (Literal, optional):  What to do if the table already exists. Defaults to "fail".
             if_empty (Literal, optional): What to do if Parquet file is empty. Defaults to "skip".
             duckdb_credentials (dict, optional): Credentials for the DuckDB connection. Defaults to None.
-
+            timeout(int, optional): The amount of time (in seconds) to wait while running this task before
+                a timeout occurs. Defaults to 3600.
         """
         # SQLServerToDF
         self.sql_query = sql_query
         self.sqlserver_config_key = sqlserver_config_key
+        self.timeout = timeout
 
         # DuckDBCreateTableFromParquet
         self.local_file_path = local_file_path
@@ -54,12 +55,13 @@ class SQLServerToDuckDB(Flow):
         super().__init__(*args, name=name, **kwargs)
 
         self.create_duckdb_table_task = DuckDBCreateTableFromParquet(
-            credentials=duckdb_credentials
+            credentials=duckdb_credentials, timeout=timeout
         )
 
         self.gen_flow()
 
     def gen_flow(self) -> Flow:
+        df_task = SQLServerToDF(timeout=self.timeout)
         df = df_task.bind(
             config_key=self.sqlserver_config_key, query=self.sql_query, flow=self
         )
