@@ -1,8 +1,9 @@
+import os
 import json
 import base64
 import warnings
 import asyncio
-from typing import Any, Dict, List, Literal
+from typing import Any, Dict, List, Literal, Optional
 from io import StringIO
 
 import prefect
@@ -10,6 +11,7 @@ import aiohttp
 import pandas as pd
 from datetime import datetime, timedelta
 from aiolimiter import AsyncLimiter
+from prefect.engine import signals
 
 from viadot.config import local_config
 from viadot.sources.base import Source
@@ -23,13 +25,10 @@ warnings.simplefilter("ignore")
 class Genesys(Source):
     def __init__(
         self,
-        media_type_list: List[str] = None,
-        queueIds_list: List[str] = None,
-        data_to_post_str: str = None,
+        view_type: str = "queue_performance_detail_view",
         ids_mapping: Dict[str, Any] = None,
         start_date: str = None,
         end_date: str = None,
-        days_interval: int = 1,
         report_name: str = None,
         file_extension: Literal["xls", "xlsx", "csv"] = "csv",
         credentials_genesys: Dict[str, Any] = None,
@@ -44,13 +43,10 @@ class Genesys(Source):
         Genesys connector which allows for reports scheduling, listing and downloading into Data Frame or specified format output.
 
         Args:
-            media_type_list (List[str], optional):  List of specific media types. Defaults to None.
-            queueIds_list (List[str], optional):  List of specific queues ids. Defaults to None.
-            data_to_post_str (str, optional):  String template to generate json body. Defaults to None.
+            view_type (str, optional): The type of view export job to be created. Defaults to "queue_performance_detail_view".
             ids_mapping (str, optional): Dictionary mapping for converting IDs to strings. Defaults to None.
             start_date (str, optional):  Start date of the report. Defaults to None.
             end_date (str, optional):  End date of the report. Defaults to None.
-            days_interval (int, optional):  How many days report should include. Defaults to None.
             report_name (str, optional): Name of the report. Defaults to None.
             file_extension (Literal[xls, xlsx, csv;], optional): file extensions for downloaded files. Defaults to "csv".
             credentials_genesys (Dict[str, Any], optional): Credentials to connect with Genesys API containing CLIENT_ID,
@@ -81,6 +77,7 @@ class Genesys(Source):
 
         super().__init__(*args, credentials=self.credentials_genesys, **kwargs)
 
+        self.view_type = view_type
         self.schedule_id = schedule_id
         self.report_name = report_name
         self.environment = environment
@@ -89,12 +86,9 @@ class Genesys(Source):
 
         self.start_date = start_date
         self.end_date = end_date
-        self.days_interval = days_interval
-        self.media_type_list = media_type_list
-        self.queueIds_list = queueIds_list
-        self.data_to_post_str = data_to_post_str
         self.file_extension = file_extension
         self.ids_mapping = ids_mapping
+        self.count = iter(range(99999))
 
         if self.schedule_id is None:
             self.schedule_id = self.credentials.get("SCHEDULE_ID", None)
@@ -112,7 +106,6 @@ class Genesys(Source):
                     "IDS_MAPPING is not provided in you credentials or is not a dictionary."
                 )
 
-        self.post_data_list = []
         self.report_data = []
 
     @property
@@ -142,6 +135,7 @@ class Genesys(Source):
             body=request_body,
             headers=request_headers,
             method="POST",
+            timeout=3600,
         )
         if verbose:
             if response.status_code == 200:
@@ -158,55 +152,17 @@ class Genesys(Source):
 
         return request_headers
 
-    def genesys_generate_body(self):
-        """
-        Function that generate json body for Post request method.
+    def genesys_generate_exports(
+        self, post_data_list: List[str], end_point: str = "reporting/exports"
+    ) -> Optional[dict]:
+        """Function that make POST request method to generate export reports.
 
-        example string:
-            example_raw_json_body_string = '''{
-                "name": f"QUEUE_PERFORMANCE_DETAIL_VIEW_{media}",
-                "timeZone": "UTC",
-                "exportFormat": "CSV",
-                "interval": f"{end_date}T23:00:00/{start_date}T23:00:00",
-                "period": "PT30M",
-                "viewType": f"QUEUE_PERFORMANCE_DETAIL_VIEW",
-                "filter": {"mediaTypes": [f"{media}"], "queueIds": [f"{queueid}"], "directions":["inbound"],},
-                "read": True,
-                "locale": "en-us",
-                "hasFormatDurations": True,
-                "hasSplitFilters": True,
-                "excludeEmptyRows": True,
-                "hasSplitByMedia": True,
-                "hasSummaryRow": True,
-                "csvDelimiter": "COMMA",
-                "hasCustomParticipantAttributes": True,
-                "recipientEmails": [],
-                }'''
+        Args:
+            post_data_list (List[str], optional): List of string templates to generate json body. Defaults to None.
+            end_point (str, optional): Final end point for Genesys connection. Defaults to "reporting/exports".
 
-        Returns: self.post_data_list (List[str]): List of formated POST body.
-
-        """
-
-        if self.start_date is None and self.end_date is None:
-            today = datetime.now()
-            yesterday = today - timedelta(days=self.days_interval)
-            start_date = today.strftime("%Y-%m-%d")
-            end_date = yesterday.strftime("%Y-%m-%d")
-        else:
-            start_date = self.start_date
-            end_date = self.end_date
-
-        for media in self.media_type_list:
-            for queueid in self.queueIds_list:
-                data_to_post = eval(self.data_to_post_str)
-
-                self.post_data_list.append(data_to_post)
-
-        return self.post_data_list
-
-    def genesys_generate_exports(self):
-        """
-        Function that make POST request method to generate export reports.
+        Returns:
+            Optional[dict]: Dict when the "conversations" endpoint is called, otherwise returns None.
         """
 
         limiter = AsyncLimiter(2, 15)
@@ -215,17 +171,18 @@ class Genesys(Source):
         async def generate_post():
             cnt = 0
 
-            for data_to_post in self.post_data_list:
+            for data_to_post in post_data_list:
                 if cnt < 10:
                     payload = json.dumps(data_to_post)
                     async with aiohttp.ClientSession() as session:
                         await semaphore.acquire()
                         async with limiter:
                             async with session.post(
-                                f"https://api.{self.environment}/api/v2/analytics/reporting/exports",
+                                f"https://api.{self.environment}/api/v2/analytics/{end_point}",
                                 headers=self.authorization_token,
                                 data=payload,
                             ) as resp:
+                                global new_report
                                 new_report = await resp.read()
                                 self.logger.info(
                                     f"Generated report export --- \n {payload}."
@@ -240,6 +197,9 @@ class Genesys(Source):
         coroutine = generate_post()
         loop.run_until_complete(coroutine)
 
+        if end_point == "conversations/details/query":
+            return json.loads(new_report.decode("utf-8"))
+
     def load_reporting_exports(self, page_size: int = 100, verbose: bool = False):
         """
         GET method for reporting export.
@@ -266,7 +226,7 @@ class Genesys(Source):
             self.logger.error(f"Failed to loaded all exports. - {new_report.content}")
             raise APIError("Failed to loaded all exports.")
 
-    def get_reporting_exports_data(self):
+    def get_reporting_exports_data(self) -> None:
         """
         Function that generate list of reports metadata for further processing steps.
         """
@@ -280,8 +240,11 @@ class Genesys(Source):
                     tmp = [
                         entity.get("id"),
                         entity.get("downloadUrl"),
-                        entity.get("filter").get("queueIds")[0],
-                        entity.get("filter").get("mediaTypes")[0],
+                        entity.get("filter").get("queueIds", [-1])[0],
+                        entity.get("filter").get("mediaTypes", [-1])[0],
+                        entity.get("viewType"),
+                        entity.get("interval"),
+                        entity.get("status"),
                     ]
                     self.report_data.append(tmp)
             assert len(self.report_data) > 0
@@ -319,11 +282,10 @@ class Genesys(Source):
         df = pd.read_csv(StringIO(response_file.content.decode("utf-8")))
         if drop_duplicates is True:
             df.drop_duplicates(inplace=True, ignore_index=True)
-        df.to_csv(f"{path}{final_file_name}", index=False, sep=sep)
+        df.to_csv(os.path.join(path, final_file_name), index=False, sep=sep)
 
     def download_all_reporting_exports(
-        self,
-        store_file_names: bool = True,
+        self, store_file_names: bool = True, path: str = ""
     ) -> List[str]:
         """
         Get information form data report and download all files.
@@ -343,11 +305,47 @@ class Genesys(Source):
             self.logger.info("IDS_MAPPING loaded from local credential.")
 
         for single_report in self.report_data:
-            file_name = (
-                temp_ids_mapping.get(single_report[2]) + "_" + single_report[-1]
-            ).upper()
+            self.logger.info(single_report)
+            if single_report[-1] == "RUNNING":
+                self.logger.warning(
+                    "The request is still in progress and will be deleted, consider add more seconds in `view_type_time_sleep` parameter."
+                )
+                continue
+            elif single_report[-1] == "FAILED":
+                self.logger.warning(
+                    "This message 'FAILED_GETTING_DATA_FROM_SERVICE' raised during script execution."
+                )
+                continue
+            elif self.start_date not in single_report[5]:
+                self.logger.warning(
+                    f"The report with ID {single_report[0]} doesn't match with the interval date that you have already defined. \
+                        The report won't be downloaded but will be deleted."
+                )
+                continue
+
+            if single_report[4].lower() == "queue_performance_detail_view":
+                file_name = (
+                    temp_ids_mapping.get(single_report[2]) + "_" + single_report[3]
+                ).upper()
+            elif single_report[4].lower() in [
+                "agent_performance_summary_view",
+                "agent_status_summary_view",
+            ]:
+                date = self.start_date.replace("-", "")
+                file_name = self.view_type.upper() + "_" + f"{date}"
+            elif single_report[4].lower() in [
+                "agent_status_detail_view",
+            ]:
+                date = self.start_date.replace("-", "")
+                file_name = self.view_type.upper() + f"_{next(self.count)}_" + f"{date}"
+            else:
+                raise signals.SKIP(
+                    message=f"View type {self.view_type} not defined in viadot, yet..."
+                )
+
             self.download_report(
                 report_url=single_report[1],
+                path=path,
                 output_file_name=file_name,
                 file_extension=self.file_extension,
             )
@@ -360,7 +358,72 @@ class Genesys(Source):
             self.logger.info("Successfully genetared file names list.")
             return file_name_list
 
-    def get_analitics_url_report(self):
+    def generate_reporting_export(
+        self, data_to_post: Dict[str, Any], verbose: bool = False
+    ) -> int:
+        """
+        POST method for reporting export.
+
+        Args:
+            data_to_post (Dict[str, Any]): json format of POST body.
+            verbose (bool, optional): Decide if enable logging.
+
+        Returns:
+            new_report.status_code: status code
+        """
+        payload = json.dumps(data_to_post)
+        new_report = handle_api_response(
+            url=f"https://api.{self.environment}/api/v2/analytics/reporting/exports",
+            headers=self.authorization_token,
+            method="POST",
+            body=payload,
+        )
+        if verbose:
+            if new_report.status_code == 200:
+                self.logger.info("Succesfully generated new export.")
+            else:
+                self.logger.error(
+                    f"Failed to generated new export. - {new_report.content}"
+                )
+                raise APIError("Failed to generated new export.")
+        return new_report.status_code
+
+    def delete_reporting_exports(self, report_id) -> int:
+        """DELETE method for deleting particular reporting exports.
+
+        Args:
+            report_id (str): defined at the end of report url.
+
+        Returns:
+            delete_method.status_code: status code
+        """
+        delete_method = handle_api_response(
+            url=f"https://api.{self.environment}/api/v2/analytics/reporting/exports/{report_id}",
+            headers=self.authorization_token,
+            method="DELETE",
+        )
+        if delete_method.status_code < 300:
+            self.logger.info("Successfully deleted report from Genesys API.")
+
+        else:
+            self.logger.error(
+                f"Failed to deleted report from Genesys API. - {delete_method.content}"
+            )
+            raise APIError("Failed to deleted report from Genesys API.")
+
+        return delete_method.status_code
+
+    def delete_all_reporting_exports(self) -> None:
+        """
+        Function that deletes all reporting from self.reporting_data list.
+        """
+        for report in self.report_data:
+            status_code = self.delete_reporting_exports(report_id=report[0])
+            assert status_code < 300
+
+        self.logger.info("Successfully removed all reports.")
+
+    def get_analitics_url_report(self) -> str:
         """
         Fetching analytics report url from json response.
 
@@ -425,36 +488,6 @@ class Genesys(Source):
             raise APIError("Failed to scheduled new report.")
         return new_report.status_code
 
-    def generate_reporting_export(
-        self, data_to_post: Dict[str, Any], verbose: bool = False
-    ) -> int:
-        """
-        POST method for reporting export.
-
-        Args:
-            data_to_post (Dict[str, Any]): json format of POST body.
-            verbose (bool, optional): Decide if enable logging.
-
-        Returns:
-            new_report.status_code: status code
-        """
-        payload = json.dumps(data_to_post)
-        new_report = handle_api_response(
-            url=f"https://api.{self.environment}/api/v2/analytics/reporting/exports",
-            headers=self.authorization_token,
-            method="POST",
-            body=payload,
-        )
-        if verbose:
-            if new_report.status_code == 200:
-                self.logger.info("Succesfully generated new export.")
-            else:
-                self.logger.error(
-                    f"Failed to generated new export. - {new_report.content}"
-                )
-                raise APIError("Failed to generated new export.")
-        return new_report.status_code
-
     def to_df(self, report_url: str = None):
         """Download genesys data into a pandas DataFrame.
 
@@ -502,41 +535,3 @@ class Genesys(Source):
             raise APIError("Failed to deleted report from Genesys API.")
 
         return delete_method.status_code
-
-    def delete_reporting_exports(self, report_id):
-        """DELETE method for deleting particular reporting exports.
-
-        Args:
-            report_id (str): defined at the end of report url.
-
-        Returns:
-            delete_method.status_code: status code
-        """
-        delete_method = handle_api_response(
-            url=f"https://api.{self.environment}/api/v2/analytics/reporting/exports/{report_id}",
-            headers=self.authorization_token,
-            method="DELETE",
-        )
-        if delete_method.status_code < 300:
-            self.logger.info("Successfully deleted report from Genesys API.")
-
-        else:
-            self.logger.error(
-                f"Failed to deleted report from Genesys API. - {delete_method.content}"
-            )
-            raise APIError("Failed to deleted report from Genesys API.")
-
-        return delete_method.status_code
-
-    def delete_all_reporting_exports(self):
-        """
-        Function that deletes all reporting from self.reporting_data list.
-
-        Returns:
-            delete_method.status_code: status code
-        """
-        for report in self.report_data:
-            status_code = self.delete_reporting_exports(report_id=report[0])
-            assert status_code < 300
-
-        self.logger.info("Successfully removed all reports.")
