@@ -33,7 +33,7 @@ from .salesforce import SalesforceBulkUpsert, SalesforceToDF, SalesforceUpsert
 from .sharepoint import SharepointToDF
 from .sqlite import SQLiteInsert, SQLiteQuery, SQLiteSQLtoDF
 from .supermetrics import SupermetricsToCSV, SupermetricsToDF
-from .genesys import GenesysToCSV, GenesysToDF
+from .genesys import GenesysToCSV
 
 try:
     from .sap_rfc import SAPRFCToDF
@@ -47,4 +47,4 @@ from .epicor import EpicorOrdersToDF
 
 from .sftp import SftpToDF, SftpList
 from .mindful import MindfulToCSV
-
+from .mediatool import MediatoolToDF
