@@ -3,7 +3,7 @@ import pandas as pd
 from prefect import Task
 from prefect.utilities import logging
 from prefect.utilities.tasks import defaults_from_attrs
-from ..sources import Outlook
+from viadot.sources import Outlook
 
 logger = logging.get_logger()
 
@@ -17,7 +17,7 @@ class OutlookToDF(Task):
         credentials: Dict[str, Any] = None,
         output_file_extension: str = ".csv",
         limit: int = 10000,
-        timeout: int = 1200,
+        timeout: int = 3600,
         *args: List[Any],
         **kwargs: Dict[str, Any],
     ):
